@@ -11,7 +11,7 @@
 #define SHELL_Q '"'
 #define DL_DFLT_NAME "libpari.dll"
 
-#define PARIVERSION "GP/PARI CALCULATOR Version 2.1.3 (released)"
+#define PARIVERSION "GP/PARI CALCULATOR Version 2.1.5 (release)"
 #ifdef __cplusplus
 #  define PARIINFO_PRE "C++"
 #else
@@ -27,8 +27,10 @@
 #  define PARIINFO_POST "ix86 running Windows 3.2 (ix86 kernel) 32-bit version"
 #endif
 #define PARIINFO PARIINFO_PRE/**/PARIINFO_POST
+#define PARI_VERSION_CODE 131333
+#define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 
-#define PARI_BYTE_ORDER    1234
+#define PARI_DOUBLE_FORMAT 1
 #ifdef _MSC_VER /* MSVC inline directive */
 #  define INLINE __inline
 #endif
@@ -65,8 +67,8 @@
 /* Timings: Don't use times because of the HZ / CLK_TCK confusion. */
 #  define USE_FTIME 1
 #  define HAS_STRFTIME
- /* comment this one if not on NT ??? */
-#  define HAS_OPENDIR
+/* This might work on NT ??? */
+/* #  define HAS_OPENDIR */
 #endif
 
 #endif
