@@ -1,4 +1,4 @@
-/* $Id: alglin2.c,v 1.21 2000/11/08 11:15:23 karim Exp $
+/* $Id: alglin2.c,v 1.21.2.4 2002/11/15 13:04:51 bill Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -445,7 +445,8 @@ conjvec(GEN x,long prec)
     case t_VEC: case t_COL:
       lx=lg(x); z=cgetg(lx,t_MAT);
       for (i=1; i<lx; i++) z[i]=(long)conjvec((GEN)x[i],prec);
-      s=lg(z[1]);
+      if (lx == 1) break;
+      s = lg(z[1]);
       for (i=2; i<lx; i++)
 	if (lg(z[i])!=s) err(talker,"incompatible field degrees in conjvec");
       break;
@@ -512,10 +513,12 @@ assmat(GEN x)
       p1[j] = lneg((GEN)x[j+1]);
   else
   {
-    p2 = (GEN)x[lx+1]; gnegz(p2,p2);
+    ulong av = avma;
+    p2 = gclone(gneg((GEN)x[lx+1]));
+    avma = av;
     for (j=1; j<lx; j++)
       p1[j] = ldiv((GEN)x[j+1],p2);
-    gnegz(p2,p2);
+    gunclone(p2);
   }
   return y;
 }
@@ -681,7 +684,7 @@ sqred2(GEN a, long no_signature)
   long av,tetpil,av1,lim,n,i,j,k,l,sp,sn,t;
 
   if (typ(a)!=t_MAT) err(typeer,"sqred2");
-  n=lg(a); if (lg(a[1]) != n) err(mattype1,"sqred2");
+  n=lg(a); if (n > 1 && lg(a[1]) != n) err(mattype1,"sqred2");
 
   av=avma; mun=negi(gun); r=new_chunk(n);
   for (i=1; i<n; i++) r[i]=1;
