@@ -1,4 +1,4 @@
-/* $Id: arith2.c,v 1.18.2.2 2001/10/25 11:43:28 cvsadmin Exp $
+/* $Id: arith2.c,v 1.18.2.3 2002/09/30 13:50:51 bill Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -943,7 +943,7 @@ sumdivk(GEN n, long k)
   if (!signe(n)) err(arither2);
   if (is_pm1(n)) return gun;
   k1 = k; n1 = n;
-  if (k==-1) { m=sumdiv(n); goto fin; }
+  if (k==-1) { m=sumdiv(n); k=1; goto fin; }
   if (k<0)  k = -k;
   v=vali(n);
   n=absi(shifti(n,-v));
