@@ -1,4 +1,4 @@
-/* $Id: subfield.c,v 1.7.2.2 2001/10/04 16:24:49 cvsadmin Exp $
+/* $Id: subfield.c,v 1.7.2.3 2002/02/27 17:33:19 bill Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -855,11 +855,14 @@ ffinit(GEN p,long n,long v)
   if (n<=0) err(talker,"non positive degree in ffinit");
   if (typ(p) != t_INT) err(typeer,"ffinit");
   if (v<0) v = 0;
-  for(;; avma = av)
-  {
-    pol = gadd(gpowgs(polx[v],n), FpX_rand(n-1,v, p));
-    if (is_irred_mod_p(pol, p)) break;
-  }
+  if (n == 2 && egalii(p,gdeux))
+    pol=cyclo(3,v);
+  else
+    for(;; avma = av)
+    {
+      pol = gadd(gpowgs(polx[v],n), FpX_rand(n-1,v, p));
+      if (is_irred_mod_p(pol, p)) break;
+    }
   return gerepileupto(av, Fp_pol(pol,p));
 }
 
